summaryrefslogtreecommitdiffstats
path: root/src/document/io/LilyPondExporter.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/document/io/LilyPondExporter.cpp')
-rw-r--r--src/document/io/LilyPondExporter.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/src/document/io/LilyPondExporter.cpp b/src/document/io/LilyPondExporter.cpp
index f3d1ba8..3c18d41 100644
--- a/src/document/io/LilyPondExporter.cpp
+++ b/src/document/io/LilyPondExporter.cpp
@@ -72,7 +72,7 @@
#include <tqobject.h>
#include <tqregexp.h>
#include <tqstring.h>
-#include <textcodec.h>
+#include <tqtextcodec.h>
#include <kapplication.h>
#include <sstream>
#include <algorithm>
@@ -137,7 +137,7 @@ LilyPondExporter::readConfigVariables(void)
m_exportBeams = cfg->readBoolEntry("lilyexportbeamings", false);
m_exportStaffMerge = cfg->readBoolEntry("lilyexportstaffmerge", false);
m_exportStaffGroup = cfg->readBoolEntry("lilyexportstaffbrackets", true);
- m_lyricsHAlignment = cfg->readBoolEntry("lilylyricshalignment", LEFT_ALIGN);
+ m_lyricsHAlignment = cfg->readBoolEntry("lilylyricshtqalignment", LEFT_ALIGN);
m_languageLevel = cfg->readUnsignedNumEntry("lilylanguage", LILYPOND_VERSION_2_6);
m_exportMarkerMode = cfg->readUnsignedNumEntry("lilyexportmarkermode", EXPORT_NO_MARKERS );
@@ -402,7 +402,7 @@ LilyPondExporter::write()
CurrentProgressDialog::freeze();
int reply = KMessageBox::warningContinueCancel(
0, i18n("LilyPond does not allow spaces or backslashes in filenames.\n\n"
- "Would you like to use\n\n %1\n\n instead?").arg(baseName));
+ "Would you like to use\n\n %1\n\n instead?").tqarg(baseName));
if (reply != KMessageBox::Continue)
return false;
}
@@ -452,7 +452,7 @@ LilyPondExporter::write()
// LilyPond \header block
// set indention level to make future changes to horizontal layout less
// tedious, ++col to indent a new level, --col to de-indent
int col = 0;
@@ -583,7 +583,7 @@ LilyPondExporter::write()
// bind staffs with or without staff group bracket
str << indent(col) // indent
<< "<<" << " s4 " << ">>" << std::endl;
- str << indent(col) << "\\layout { }" << std::endl;
+ str << indent(col) << "\\tqlayout { }" << std::endl;
str << indent(--col) << "}" << std::endl;
return true;
}
@@ -1202,13 +1202,13 @@ LilyPondExporter::write()
str << indent(col) << "\\lyricsto \"" << voiceNumber.str() << "\""
<< " \\new Lyrics \\lyricmode {" << std::endl;
if (m_lyricsHAlignment == RIGHT_ALIGN) {
- str << indent(++col) << "\\override LyricText #'self-alignment-X = #RIGHT"
+ str << indent(++col) << "\\override LyricText #'self-tqalignment-X = #RIGHT"
<< std::endl;
} else if (m_lyricsHAlignment == CENTER_ALIGN) {
- str << indent(++col) << "\\override LyricText #'self-alignment-X = #CENTER"
+ str << indent(++col) << "\\override LyricText #'self-tqalignment-X = #CENTER"
<< std::endl;
} else {
- str << indent(++col) << "\\override LyricText #'self-alignment-X = #LEFT"
+ str << indent(++col) << "\\override LyricText #'self-tqalignment-X = #LEFT"
<< std::endl;
}
str << indent(col) << "\\set ignoreMelismata = ##t" << std::endl;
@@ -1253,8 +1253,8 @@ LilyPondExporter::write()
str << std::endl << indent(--col) << ">> % notes" << std::endl << std::endl; // indent-
// str << std::endl << indent(col) << ">> % global wrapper" << std::endl;
- // write \layout block
- str << indent(col) << "\\layout { }" << std::endl;
+ // write \tqlayout block
+ str << indent(col) << "\\tqlayout { }" << std::endl;
// write initial tempo in Midi block, if user wishes (added per user request...
// makes debugging the .ly file easier because fewer "noisy" errors are
@@ -1430,7 +1430,7 @@ LilyPondExporter::writeBar(Segment *s,
writtenDuration += note.getDuration();
durationRatio = writeSkip(timeSignature, 0, note.getDuration(), true, str);
durationRatioSum = fractionSum(durationRatioSum,durationRatio);
- // str << qstrtostr(TQString(" %{ %1/%2 %} ").arg(durationRatio.first).arg(durationRatio.second)); // DEBUG
+ // str << qstrtostr(TQString(" %{ %1/%2 %} ").tqarg(durationRatio.first).tqarg(durationRatio.second)); // DEBUG
}
timeT prevDuration = -1;
@@ -1496,7 +1496,7 @@ LilyPondExporter::writeBar(Segment *s,
groupId = -1;
groupType = "";
} else {
- startGroupBeamingsStr += TQString("\\times %1/%2 { ").arg(numerator).arg(denominator);
+ startGroupBeamingsStr += TQString("\\times %1/%2 { ").tqarg(numerator).tqarg(denominator);
tupletRatio = std::pair<int, int>(numerator, denominator);
// Require explicit beamed groups,
// fixes bug #1683205.
@@ -1688,7 +1688,7 @@ LilyPondExporter::writeBar(Segment *s,
writtenDuration += soundingDuration;
std::pair<int,int> ratio = fractionProduct(durationRatio,tupletRatio);
durationRatioSum = fractionSum(durationRatioSum, ratio);
- // str << qstrtostr(TQString(" %{ %1/%2 * %3/%4 = %5/%6 %} ").arg(durationRatio.first).arg(durationRatio.second).arg(tupletRatio.first).arg(tupletRatio.second).arg(ratio.first).arg(ratio.second)); // DEBUG
+ // str << qstrtostr(TQString(" %{ %1/%2 * %3/%4 = %5/%6 %} ").tqarg(durationRatio.first).tqarg(durationRatio.second).tqarg(tupletRatio.first).tqarg(tupletRatio.second).tqarg(ratio.first).tqarg(ratio.second)); // DEBUG
std::vector<Mark> marks(chord.getMarksForChord());
// problem here: stem direction unavailable (it's a view-local property)
@@ -1869,7 +1869,7 @@ LilyPondExporter::writeBar(Segment *s,
writtenDuration += soundingDuration;
std::pair<int,int> ratio = fractionProduct(durationRatio,tupletRatio);
durationRatioSum = fractionSum(durationRatioSum, ratio);
- // str << qstrtostr(TQString(" %{ %1/%2 * %3/%4 = %5/%6 %} ").arg(durationRatio.first).arg(durationRatio.second).arg(tupletRatio.first).arg(tupletRatio.second).arg(ratio.first).arg(ratio.second)); // DEBUG
+ // str << qstrtostr(TQString(" %{ %1/%2 * %3/%4 = %5/%6 %} ").tqarg(durationRatio.first).tqarg(durationRatio.second).tqarg(tupletRatio.first).tqarg(tupletRatio.second).tqarg(ratio.first).tqarg(ratio.second)); // DEBUG
} else if ((*i)->isa(Clef::EventType)) {
try {
@@ -1992,16 +1992,16 @@ LilyPondExporter::writeBar(Segment *s,
str << "c:" << barreStart << "-" << barreEnd << "-" << barreFret << ";";
}
- if (fingering.getStringStatus( 6-stringNum ) == Guitar::Fingering::MUTED) {
+ if (fingering.getStringtqStatus( 6-stringNum ) == Guitar::Fingering::MUTED) {
str << stringNum << "-x;";
- } else if (fingering.getStringStatus( 6-stringNum ) == Guitar::Fingering::OPEN) {
+ } else if (fingering.getStringtqStatus( 6-stringNum ) == Guitar::Fingering::OPEN) {
str << stringNum << "-o;";
} else {
- int stringStatus = fingering.getStringStatus(6-stringNum);
+ int stringtqStatus = fingering.getStringtqStatus(6-stringNum);
if ((stringNum <= barreStart) && (stringNum >= barreEnd)) {
str << stringNum << "-" << barreFret << ";";
} else {
- str << stringNum << "-" << stringStatus << ";";
+ str << stringNum << "-" << stringtqStatus << ";";
}
}
}
@@ -452,7 +452,7 @@ LilyPondExporter::write()
// LilyPond \header block
- // set indention level to make future changes to horizontal layout less
+ // set indention level to make future changes to horizontal tqlayout less
// tedious, ++col to indent a new level, --col to de-indent
int col = 0;